@@ -9,6 +9,7 @@ globalVariables(c("a_vals",
                   "adj_value",
                   "b_sqrt_a",
                   "b_vals",
+                  "CI_params",
                   "ei",
                   "esp2013",
                   "estimate",
@@ -40,6 +41,7 @@ globalVariables(c("a_vals",
                   "rii_MAD",
                   "rii_uppercl",
                   "sd",
+                  "se_calc",
                   "SeSE_2b_removed",
                   "sii",
                   "sii_lowercl",
